{% load cms_tags %}
<div class="{{ instance.class_name }}"{% if instance.inline_style %} style="{{ instance.inline_style }}"{% endif %}>
{% for plugin in instance.child_plugin_instances %}
    	{% render_plugin plugin %}
{% endfor %}
</div>